/****************
 * Stanford Law Review Paper Table 2a.2
 * Zheng's Dataset 
 * Vernick coding
 * Lott-Spline Model
 * 1977-1999
 ********************/

clear
set memory 200000
set matsize 300
set more off
capture log close
log using "Table2a.2.log", replace
#delimit ;
use "wentong7799_vernick.dta";

/** Read in data
 * state, year (1960), fipsstat, pop (population), pop1(once-lagged
 * population), black (black population in 1000s), metro (metropolitan 
 * population in 1000s), p15t17 (population of ages 15 to 17 in 1000s), 
 * p18t24 (population of ages 18 to 24 in 1000s), p25t34 (population of
 * ages 25 to 34 in 1000s), income (per capita income, nominal), price
 * (price deflator), unemp (unemployment rate), poverty (percent of 
 * persons below poverty line), police (number of sworn police officers),
 * police1 (number of sworn police officers, once-lagged), prisoners 
 * (prison population), prisoners1 (prison population, once-lagged),
 * alcohol (alcohol consumption, in 1000s of gallons), governor (1 if 
 * democrat, 2 if repulican, 3 if independent, 4 if other), violent 
 * (violent crime, per 100,000), murder (per 100,000), rape (per 100,000),
 * assault (aggravated assault, per 100,000), robbery (per 100,000),
 * property (per 100,000), burglary (per 100,000), larceny (per 100,000),
 * auto (auto vehicle theft, per 100,000)
 **/

/** Generate crime variables **/

gen lvio=ln(violent);
gen lmur=ln(murder);
gen lrap=ln(rape);
gen laga=ln(assault);
gen lrob=ln(robbery);
gen lpro=ln(property);
gen lbur=ln(burglary);
gen llar=ln(larceny);
gen laut=ln(auto);

/** Generate other variables **/

gen black_per=black*1000/pop*100;
gen metro_per=metro*1000/pop*100;
gen age1_per=p15t17*1000/pop*100;
gen age2_per=p18t24*1000/pop*100;
gen age3_per=p25t34*1000/pop*100;
gen rincome=income*(100/price);
gen police_per1=police1/pop1*100000;
gen prison_per1=prisoners1/pop1*100000;
gen alcohol_per=alcohol*1000/pop;

/**Generate year dummies **/

gen yr77=0;
gen yr78=0;
gen yr79=0;
gen yr80=0;
gen yr81=0;
gen yr82=0;
gen yr83=0;
gen yr84=0;
gen yr85=0;
gen yr86=0;
gen yr87=0;
gen yr88=0;
gen yr89=0;
gen yr90=0;
gen yr91=0;
gen yr92=0;
gen yr93=0;
gen yr94=0;
gen yr95=0;
gen yr96=0;
gen yr97=0;
gen yr98=0;
gen yr99=0;

replace yr77=1 if year==1977;
replace yr78=1 if year==1978;
replace yr79=1 if year==1979;
replace yr80=1 if year==1980;
replace yr81=1 if year==1981;
replace yr82=1 if year==1982;
replace yr83=1 if year==1983;
replace yr84=1 if year==1984;
replace yr85=1 if year==1985;
replace yr86=1 if year==1986;
replace yr87=1 if year==1987;
replace yr88=1 if year==1988;
replace yr89=1 if year==1989;
replace yr90=1 if year==1990;
replace yr91=1 if year==1991;
replace yr92=1 if year==1992;
replace yr93=1 if year==1993;
replace yr94=1 if year==1994;
replace yr95=1 if year==1995;
replace yr96=1 if year==1996;
replace yr97=1 if year==1997;
replace yr98=1 if year==1998;
replace yr99=1 if year==1999;

/* Generate shall law dummies */
replace shalll=0;
replace shalll=1 if year-1900>yradopt & yradopt~=0;
replace shalll=0 if yradopt<77;

gen ttt1=year-1976 if yradopt>77;
replace ttt1=0 if ttt1==.;
gen aftr=year-1900-yradopt if year>1900+yradopt & yradopt>77;
replace aftr=0 if aftr==.;

/*Crime	Murder	Rape	Assault	Robbery	Crime	Theft	Burglary	Larceny	*/

areg  lvio aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust; 
outreg aftr using Table2a.2.xls, replace noparen nolabel coefastr se 3aster;

areg  lmur aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  lrap aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  laga aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  lrob aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  lpro aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  laut aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  lbur aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;

areg  llar aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg aftr using Table2a.2.xls, append noparen nolabel coefastr se 3aster;


log close;
