/****************
 * Stanford Law Review Paper Table 5
 * Vernick's coding, Incarceration Rate
 * Dummy Variable Model
 * 1977-1999 
 ********************/

clear
capture log close
set memory 200000
set matsize 300
set more off
log using "Table5.log", replace
use "..\FINAL DATASET"
drop if year<77
#delimit ;

replace vernick_shall=0 if vernick_shall<77;

/* Every non-demographic control */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.1.xls, append noparen nolabel coefastr se 3aster;


/* Every non-demographic control + black and white males ages 10-19 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019 pwm1019 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.2.xls, append noparen nolabel coefastr se 3aster;



/* Every non-demographic control + black and white males ages 10-29 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm2029 pwm1019-pwm2029 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.3.xls, append noparen nolabel coefastr se 3aster;



/* Every non-demographic control + black and white males ages 10-49 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.4.xls, append noparen nolabel coefastr se 3aster;


/* Every non-demographic control + black and white males and females ages 10-49 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.5.xls, append noparen nolabel coefastr se 3aster;



/* Every non-demographic control + black and white males and females and neither b nor w males ages 10-49 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.6.xls, append noparen nolabel coefastr se 3aster;




/* Every non-demographic control + black, white, and other males and females ages 10-49 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm1019-pbm4049 pwm1019-pwm4049 pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.7.xls, append noparen nolabel coefastr se 3aster;




/* Every non-demographic explanatory variable + black and white males ages 10-o65, black and white females ages 10-49, neither males and females ages 10-49 */

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pbm* pwm* pbf1019-pbf4049 pwf1019-pwf4049 pnm1019-pnm4049 pnf1019-pnf4049 iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.8.xls, append noparen nolabel coefastr se 3aster;




/* Every explanatory variable*/

areg lvio v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, replace noparen nolabel coefastr se 3aster;
areg lmur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg lrap v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg laga v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg lrob v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg lpro v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg laut v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg lbur v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;
areg llar v_shall incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall using Table5.9.xls, append noparen nolabel coefastr se 3aster;



log close;

